@@ -2,6 +2,7 @@
 import argparse
 import matplotlib.pyplot as matplt
 import os
+import sys
 
 # my code
 import gnssrefl.gps as g
@@ -9,14 +10,10 @@ import gnssrefl.daily_avg as da
 
 from gnssrefl.utils import str2bool
 
-# changes to output requested by Kelly Enloe for JN
-# two text files will now always made - but you can override the name of the average file via command line
-
-
 def parse_arguments():
     # must input start and end year
     parser = argparse.ArgumentParser()
-    parser.add_argument("station", help="station name", type=str)
+    parser.add_argument("station", help="station name (4 ch only)", type=str)
     parser.add_argument("medfilter", help="Median filter for daily RH (m). Start with 0.25 ", type=float)
     parser.add_argument("ReqTracks", help="required number of tracks", type=int)
     parser.add_argument("-txtfile", default=None, type=str, help="Set your own output filename")
@@ -29,6 +26,7 @@ def parse_arguments():
     parser.add_argument("-azim1", default=None, type=int, help="minimum azimuth (deg)")
     parser.add_argument("-azim2", default=None, type=int, help="maximum azimuth (deg)")
     parser.add_argument("-test", default=None, type=str, help="augmentation to plot")
+    parser.add_argument("-subdir", default=None, type=str, help="non-default subdirectory for output ")
     args = parser.parse_args().__dict__
 
     # convert all expected boolean inputs from strings to booleans
@@ -40,12 +38,12 @@ def parse_arguments():
 
 
 def daily_avg(station: str , medfilter: float, ReqTracks: int, txtfile: str = None, plt: bool = True, 
-        extension: str = '', year1: int = 2005, year2: int = 2030, fr: int = 0, csv: bool = False, azim1: int = 0, azim2: int = 360, test: bool = False):
+        extension: str = '', year1: int = 2005, year2: int = 2030, fr: int = 0, csv: bool = False, azim1: int = 0, azim2: int = 360, test: bool = False, subdir: str=None):
     """
         Parameters
-        __________
+        ----------
         station : string
-            4 or 9 character ID of the station.
+            4 ch station name 
 
         medfilter : float
             Median filter for daily reflector height (m). Start with 0.25
@@ -76,19 +74,32 @@ def daily_avg(station: str , medfilter: float, ReqTracks: int, txtfile: str = No
         fr : int, optional
             GNSS frequency. Value options:
                 0 (default) : all
+
                 1 : GPS L1
+
                 2 : GPS L2
+
                 20 : GPS L2C
+
                 5 : GPS L5
+
                 101 : GLONASS L1
+
                 102 : GLONASS L2
                 201 : GALILEO E1
+
                 205 : GALILEO E5a
+
                 206 : GALILEO E6
+
                 207 : GALILEO E5b
+
                 208 : GALILEO E5
+
                 302 : BEIDOU B1
+
                 306 : BEIDOU B3
+
                 307 : BEIDOU B2
 
         csv : boolean, optional
@@ -104,18 +115,28 @@ def daily_avg(station: str , medfilter: float, ReqTracks: int, txtfile: str = No
 
         test : bool
             augmentations to the plot
+
+        subdir: str
+            non-default subdirectory for Files output
+
     """
+    if len(station) != 4:
+        print('Station names must have four characters. Exiting.')
+        sys.exit()
+
     plt2screen = plt # since variable was originally this name 
     # make sure environment variables are set
     g.check_environ_variables()
-    xdir = os.environ['REFL_CODE']
-
+    if subdir == None:
+        subdir = station
+    g.set_subdir(subdir)
 # where the summary files will be written to
-    txtdir = xdir + '/Files' 
+    xdir = os.environ['REFL_CODE']
+    txtdir = xdir + '/Files/'  + subdir
 
-    if not os.path.exists(txtdir):
-        print('make an output directory', txtdir)
-        os.makedirs(txtdir)
+    #if not os.path.exists(txtdir):
+    #    print('make an output directory', txtdir)
+    #    os.makedirs(txtdir)
 
     # set the name of the output format
     if csv:
@@ -123,7 +144,7 @@ def daily_avg(station: str , medfilter: float, ReqTracks: int, txtfile: str = No
     else:
         alldatafile = txtdir + '/' + station + '_allRH.txt' 
 
-    tv, obstimes = da.readin_plot_daily(station, extension, year1, year2, fr, alldatafile, csv, medfilter, ReqTracks,azim1,azim2,test)
+    tv, obstimes = da.readin_plot_daily(station, extension, year1, year2, fr, alldatafile, csv, medfilter, ReqTracks,azim1,azim2,test,subdir)
 
     # default is to show the plots
     if plt2screen:
