@@ -47,77 +47,89 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
                    version: int = 2, strip: bool = False, doy_end: int = None, stream: str = 'R', samplerate: int = 30,
                    debug: bool = False, dec: int = 1):
     """
-        command line interface for download_rinex.
+    command line interface for download_rinex.
+    2022 nov 17
 
-        Parameters
-        ___________
-        station : string
-            4 or 9 character ID of the station.
+    Parameters
+    ----------
+    station : string
+        4 or 9 character ID of the station.
 
-        year : integer
-            Year
+    year : integer
+        Year
 
-         month : integer
-            month
+    month : integer
+        month
 
-         day : integer
-            day
+    day : integer
+        day
 
-        rate : string, optional
-            sample rate. value options:
-                low (default) : standard rate data
-                high : high rate data
+    rate : string, optional
+        sample rate. value options:
 
-        archive : str, optional
-            Select which archive to get the files from.
-            Default is None. None means that the code will search and find an archive with the data for you.
-            value options:
-                unavco
-                sonel (global sea level observing system)
-                sopac (Scripps Orbit and Permanent Array Center)
-                cddis (NASA's Archive of Space Geodesy Data)
-                ngs (National Geodetic Survey)
-                nrcan (Natural Resources Canada)
-                bkg (German Agency for Cartography and Geodesy)
-                bfg (German Agency for water research, only Rinex 3)
-                nz (GNS, New Zealand)
-                ga (Geoscience Australia)
-                bev (Austria Federal Office of Metrology and Surveying)
-                jeff
-                special (reflectometry Rinex 2 files maintained by unavco)
-                all
+            low (default) : standard rate data
 
-        version : int, optional
-            Version of Rinex file. Default is 2.
-            value options:
-                2 : Rinex 2
-                3 : Rinex 3
+            high : high rate data
 
-        strip : boolean, optional
-            Whether to strip only SNR observables.  Uses teqc or gfzrnx.
-            Default is False.
+    archive : str, optional
+        Select which archive to get the files from.
+        Default is None. value options:
+
+            unavco : now earthscope
+
+            sonel : (global sea level observing system)
+
+            sopac : (Scripps Orbit and Permanent Array Center)
+
+            cddis : (NASA's Archive of Space Geodesy Data)
+
+            ngs : (National Geodetic Survey)
+
+            nrcan : (Natural Resources Canada)
+
+            bkg : (German Agency for Cartography and Geodesy)
+
+            bfg : (German Agency for water research, only Rinex 3)
+
+            nz : (GNS, New Zealand)
+
+            ga : (Geoscience Australia)
+
+            bev : (Austria Federal Office of Metrology and Surveying)
+
+            jeff : Jeff Freymueller
+
+            special : (reflectometry Rinex 2 files maintained by unavco)
+
+            all : (searches sopac,sonel,and unavco)
+
+    version : int, optional
+        Version of Rinex file. Default is 2.
+        Value options  2 or 3 
+
+    strip : boolean, optional
+        Whether to strip only SNR observables.  Uses teqc or gfzrnx.
+        Default is False.
 
 
-        doy_end : int, optional
-            End day of year to be downloaded. This is to create a range from doy to doy_end of days to get the snr files.
-            Default is None. (meaning only a single day using the doy parameter)
+    doy_end : int, optional
+        End day of year to be downloaded. This is to create a range from doy to doy_end of days to get the snr files.
+        Default is None. (meaning only a single day using the doy parameter)
 
-        stream : str, optional
-            Whether to get stream defined filenames.
-            Default is 'R'. value options:
-                R
-                S
+    stream : str, optional
+        Whether to get stream 'S' defined filenames.
+        Default is 'R'. 
 
-        samplerate : int, optional
-            Sample rate in seconds for RINEX3 only.
-            Default is 30.
+    samplerate : int, optional
+        Sample rate in seconds for RINEX3 only.
+        Default is 30.
 
-        debug : boolean, optional
-            provides screen output helpful for debugging
-            Default is False
+    debug : boolean, optional
+        provides screen output helpful for debugging
+        Default is False
 
-        dec : integer, optional
-            some highrate file downloads allow decimation. Default is 1 sec, i.e. no decimation
+    dec : integer, optional
+        some highrate file downloads allow decimation. Default is 1 sec, i.e. no decimation
     """
 
 #   make sure environment variables exist.  set to current directory if not
@@ -127,12 +139,7 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
         print('Year must have four characters: ', year)
         sys.exit()
 
-    if (day == 0):
-        # then you are using day of year as input
-        doy = month
-        year, month, day = g.ydoy2ymd(year, doy)
-    else:
-        doy, cdoy, cyyyy, cyy = g.ymd2doy(year, month, day)
+    month, day, doy, cyyyy, cyy, cdoy = g.ymd2ch(year,month,day)
 
     # allowed archives, rinex 2.11
     archive_list = ['sopac', 'unavco', 'sonel', 'cddis', 'nz', 'ga', 'bkg', 'jeff', 'ngs', 'nrcan', 'special', 'bev', 'all']
