@@ -1,8 +1,23 @@
 # -*- coding: utf-8 -*-
 """
-computers GPS week (and day of week) from y,m,d
-kristine larson
-Updated: April 3, 2019
+Parameters
+----------
+year : integer
+    full year
+
+month : integer
+     calendar month
+
+day : integer
+     day of the month
+
+Returns
+-------
+wk : int
+    GPS week
+day : int
+    GPS day of the week (0 to 6 used by the IGS)
+
 """
 import argparse
 import gnssrefl.gps as g
