@@ -19,7 +19,7 @@ from pathlib import Path
 xdir = Path(os.environ["REFL_CODE"])
 
 
-def daily_phase_plot(station, fr,datetime_dates, tv,xdir):
+def daily_phase_plot(station, fr,datetime_dates, tv,xdir,subdir):
     """
     makes a plot of daily averaged phase
 
@@ -31,14 +31,18 @@ def daily_phase_plot(station, fr,datetime_dates, tv,xdir):
     fr : int
         frequency
 
-    datetime_dates: ...
+    datetime_dates : ...
 
     tv : list of results
 
     xdir : str
         location of the results (environment variable REFL_CODE)
 
+    subdir : str
+        subdirectory in Files
+
     """
+    outdir = xdir + '/Files/' + subdir
     plt.figure(figsize=(10, 6))
     plt.plot(datetime_dates, tv[:, 2], 'bo')
     plt.ylabel('phase (degrees)')
@@ -49,7 +53,8 @@ def daily_phase_plot(station, fr,datetime_dates, tv,xdir):
     plt.grid()
     plt.gcf().autofmt_xdate()
 
-    plot_path = f'{xdir}/Files/{station}_daily_phase.png'
+    # maybe this works.  Maybe not.
+    plot_path = f'{outdir}/{station}_daily_phase.png'
     print(f"Saving figure to {plot_path}")
     plt.savefig(plot_path)
 
@@ -62,7 +67,7 @@ def make_snow_filter(station, medfilter, ReqTracks, year1, year2):
 
     Parameters
     ----------
-    station : string
+    station : str
         4 ch station name
 
     medfilter : float
@@ -122,13 +127,15 @@ def make_snow_filter(station, medfilter, ReqTracks, year1, year2):
 
 def vwc_plot(station,t_datetime, vwcdata, plot_path,circles):
     """
+    makes a plot of volumetric water content
+
     Parameters
     ----------
     station : string
         4 ch station name
 
     t_datetime : datetime 
-        observation times
+        observation times for measurements
 
     vwcdata : numpy array of floats (I think)
         volumetric water content
@@ -168,18 +175,17 @@ def vwc_plot(station,t_datetime, vwcdata, plot_path,circles):
     print(f"Saving to {plot_path}")
     plt.savefig(plot_path)
 
-
 def read_apriori_rh(station,fr):
     """
-    read the track dependent a prori reflector heights needed for
+    read the track dependent a priori reflector heights needed for
     phase & thus soil moisture.
 
     Parameters
     ----------
-    station : string
+    station : str
         four character ID, lowercase
 
-    fr : integer
+    fr : int
         frequency (e.g. 1,20)
 
     Returns
@@ -233,6 +239,21 @@ def test_func(x, a, b, rh_apriori):
 def test_func_new(x, a, b, rh_apriori,freq):
     """
     This is least squares for estimating a sine wave given a fixed frequency, freqLS
+    now freq is input so it is not hardwired for L2
+
+    Parameters
+    ----------
+    x : numpy array of floats
+        sine(elevation angle) I think
+    a : float
+        amplitude  - estimated
+    b : float
+        phase  - estimated
+    rh_apriori : float
+        reflector height (m)
+    freq : int 
+        frequency
+
     """
     if (freq == 20) or (freq == 2):
         freq_least_squares = 2*np.pi*2*rh_apriori/g.constants.wL2
@@ -363,7 +384,10 @@ def phase_tracks(station, year, doy, snr_type, fr_list, e1, e2, pele, plot, scre
                                 #test_function_apriori = partial(test_func, rh_apriori=rh_apriori)
                                 params, params_covariance = optimize.curve_fit(test_function_apriori, x_data, y_data, p0=[2, 2])
     
+
+                                # change phase to degrees
                                 phase = params[1]*180/np.pi
+                                # calculate min and max elevation angle
                                 min_el = min(x); max_el = max(x)
                                 amp = np.absolute(params[0])
                                 raw_amp = params[0]
@@ -372,6 +396,7 @@ def phase_tracks(station, year, doy, snr_type, fr_list, e1, e2, pele, plot, scre
                                     if phase > 360:
                                         phase = phase - 360
 
+                                # do not allow negative amplitudes. 
                                 if raw_amp < 0:
                                     phase = phase + 180
 
@@ -403,7 +428,7 @@ def low_pct(amp, basepercent):
     return lowval
 
 
-def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,polyorder=-99,circles=False):
+def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,polyorder=-99,circles=False,subdir=''):
     """
     Convert GPS phase to VWC. Using Clara Chew's algorithm from 
     Matlab write_vegcorrect_smc.m
@@ -412,27 +437,23 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,polyorder=
 
     Parameters
     -----------
-    station : string
+    station : str
         4 char station name
-
-    year : integer
+    year : int
         beginning year
-
-    year_end : integer
+    year_end : int
         last year
-
     plt2screen : boolean
         plots come to the screen
-
     fr : integer
         frequency
         default is L2C (20)
-
     polyorder : integer
         override on the polynomial order used in leveling
-
     circles : boolean
         final plot using circles (instead of line)
+    subdir : str
+        subdirector for $REFL_CODE/Files
 
     """
 
@@ -468,9 +489,9 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,polyorder=
     # begging for a function ...
     # overriding KE for now
     if (fr == 1):
-        fileout = myxdir + '/Files/' + station + '_phase_L1.txt'
+        fileout = myxdir + '/Files/' + subdir + '/' + station + '_phase_L1.txt'
     else:
-        fileout = myxdir + '/Files/' + station + '_phase.txt'
+        fileout = myxdir + '/Files/' + subdir + '/' + station + '_phase.txt'
 
     if os.path.exists(fileout):
         avg_phase_results = np.loadtxt(fileout, comments='%')
@@ -597,6 +618,8 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,polyorder=
     print('number of nodes', howmanynodes)
     if howmanynodes == 0:
         print('No summer nodes found. Exiting.')
+        if plt2screen:
+            plt.show()
         sys.exit()
     
     else:
@@ -622,18 +645,22 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,polyorder=
     ax.grid()
     plt.gcf().autofmt_xdate()
 
-    plot_path = f'{xdir}/Files/{station}_phase_vwc_result.png'
+    outdir = f'{xdir}/Files/{subdir}'
+
+    plot_path = f'{outdir}/{station}_phase_vwc_result.png'
     print(f"Saving to {plot_path}")
     plt.savefig(plot_path)
 
 
-    plot_path = f'{xdir}/Files/{station}_vol_soil_moisture.png'
+    plot_path = f'{outdir}/{station}_vol_soil_moisture.png'
     vwc_plot(station,t_datetime, nv, plot_path,circles) 
 
     if plt2screen:
         plt.show()
 
     vwcfile = FileManagement(station, FileTypes.volumetric_water_content).get_file_path()
+
+    vwcfile = f'{outdir}/{station}_vwc.txt'
     print('>>> VWC results being written to ', vwcfile)
     with open(vwcfile, 'w') as w:
         N = len(nv)
@@ -654,7 +681,7 @@ def convert_phase(station, year, year_end=None, plt2screen=True,fr=20,polyorder=
                 w.write(f"{fdate:10.4f} {myyear:4.0f} {mydoy:4.0f} {watercontent:8.3f} {mm:3.0f} {dd:3.0f} \n")
 
 
-def write_avg_phase(station, phase, fr,year,year_end,minvalperday,vxyz):
+def write_avg_phase(station, phase, fr,year,year_end,minvalperday,vxyz,subdir):
 
     """
     creates output file for average phase results
@@ -680,6 +707,9 @@ def write_avg_phase(station, phase, fr,year,year_end,minvalperday,vxyz):
 
     vxyz is from some other compilation
 
+    subdir : str
+        subdirectory for results
+
     Returns
     -------
     tv : numpy array with elements
@@ -702,9 +732,9 @@ def write_avg_phase(station, phase, fr,year,year_end,minvalperday,vxyz):
 
     # ultimately would like to use kelly's code here
     if (fr == 1):
-        fileout = myxdir + '/Files/' + station + '_phase_L1.txt'
+        fileout = myxdir + '/Files/'  + subdir + '/' + station + '_phase_L1.txt'
     else:
-        fileout = myxdir + '/Files/' + station + '_phase.txt'
+        fileout = myxdir + '/Files/' + subdir + '/' + station + '_phase.txt'
 
     print('Daily averaged phases will be written to : ', fileout)
     with open(fileout, 'w') as fout:
@@ -757,38 +787,3 @@ def apriori_file_exist(station,fr):
     return os.path.exists(apriori_path_f) 
 
 
-# Old code.  SHould be deleted
-# why is this being done this way!
-#years = np.floor(fdate)
-#??? why is this being done this way?
-#w.write(f"{fdate:10.4f} {years:4.0f} {doys:3.0f} {nv[iw]:8.3f} \n")
-    #if polyordernum > 0:
-    #    model = np.polyfit(t, vwc, polyordernum)
-    #    fit = np.polyval(model, t)
-        # plt.plot(t,fit,label='poly-vwc')
-        # this doesn't really help
-        # sm_vwc = seasonal_smoother(vwc, 90)
-        # plt.plot(t,sm_vwc,label='90 smoother')
-    # ‘zero’, ‘slinear’, ‘quadratic’ and ‘cubic’ refer to a spline interpolation of zeroth, first, second or third order
-    # Choosing the kind of fit based on the number of years requested to process
-    #fit_kind = {1: 'zero', 2: 'slinear', 3: 'quadratic', 4: 'cubic'}
-    # ????
-    #num_years = len(st)
-    #if num_years > 4:
-    #    num_years = 4
-    #kind = fit_kind[num_years]
-    # ignore the spline which was not to be used.
-    #st_interp = interp1d(st, sp, kind=kind, fill_value='extrapolate')
-    #new_level = st_interp(t)
-
-    # this was a kluge that was not meant to be used 
-
-    #ax.plot(t_datetime, new_level, '-', label='level')
-
-    # newl = [year[-1], doys[-1], newvwc[-1]]
-    # nodes = np.append(nodes, [newl],axis=0)
-
-                        # print(f"Year {year:4.0f} DOY {doy:3.0f} Hour {utctime:6.2f} Phase {phase:8.3f} Nv {nv:5.0f}"
-                        #       f" Azimuth {avg_azim:6.1f} Sat {sat_number:3.0f} Ampl {amp:5.2f} emin {min_el:5.2f} "
-                        #       f"emax {max_el:5.2f} DelT {del_t:6.2f} aprioriRH {rh_apriori:5.3f} freq {freq:2.0f}"
-                        #       f" estRH {max_f:6.3f} pk2noise {obs_pk2noise:6.2f} LSPAmp {max_amp:6.2f}")
