@@ -77,6 +77,7 @@ def rinex2snr(station: str, year: int, doy: int, snr: int = 66, orb: str = 'nav'
     snr : integer, optional
         SNR format. This tells the code what elevation angles to save data for. Will be the snr file ending.
     value options:
+
         66 (default) : saves all data with elevation angles less than 30 degrees
 
         99 : saves all data with elevation angles between 5 and 30 degrees
@@ -85,26 +86,56 @@ def rinex2snr(station: str, year: int, doy: int, snr: int = 66, orb: str = 'nav'
         
         50 : saves all data with elevation angles less than 10 degrees
 
+    test : str, optional.
+        value options:
+
+            gps or nav : GPS broadcast orbits 
+
+            igs : IGS precise orbits
+
+            igr : IGS rapid orbits
+            
+            201,205,206,207,208 : GALILEO E1 E5a E6,E5b,E5
+
+            302,306,207 : BEIDOU B1, B3, B2
+
     orb : string, optional
         Which orbit files to download.
         value options:
+
             gps (default) : will use GPS broadcast orbit
+
             gps+glos : will use JAXA orbits which have GPS and Glonass (usually available in 48 hours)
+
             gnss : will use GFZ orbits, which is multi-GNSS (available in 3-4 days?)
+
             nav : GPS broadcast, perfectly adequate for reflectometry.
+
             igs : IGS precise, GPS only
+
             igr : IGS rapid, GPS only
+
             jax : JAXA, GPS + Glonass, within a few days, missing block III GPS satellites
+
             gbm : GFZ Potsdam, multi-GNSS, not rapid
+
             grg : French group, GPS, Galileo and Glonass, not rapid
+
             esa : ESA, multi-GNSS
+
             gfr : GFZ rapid, GPS, Galileo and Glonass, since May 17 2021
+
+            rapid : GFZ rapid, multi-GNSS
+
+            ultra: GFZ ultra-rapid, multi-GNSS
+
             wum : (disabled) Wuhan, multi-GNSS, not rapid
 
     rate : string, optional
         The data rate
         value options:
             low (default) : standard rate data
+
             high : high rate data
 
     dec : integer, optional
@@ -115,6 +146,7 @@ def rinex2snr(station: str, year: int, doy: int, snr: int = 66, orb: str = 'nav'
         Please see documentation at https://github.com/kristinemlarson/gnssrefl to see instructions to get these.
         value options:
             False (default) : does not use fortran to translate rinex
+
             True : uses fortran to translate rinex
 
     nolook : boolean, optional
@@ -123,23 +155,38 @@ def rinex2snr(station: str, year: int, doy: int, snr: int = 66, orb: str = 'nav'
 
     archive : string, optional
         Select which archive to get the files from.
-        Default is None. None means that the code will search and find an archive with the data for you.
+        Default is None. None means that the code will search unavco,sopac and sonel.
         value options:
-            unavco (University Navstar Consortium)
-            sonel (global sea level observing system)
-            sopac (Scripps Orbit and Permanent Array Center)
-            cddis (NASA's Archive of Space Geodesy Data)
-            ngs (National Geodetic Survey)
-            nrcan (Natural Resources Canada)
-            bkg (German Agency for Cartography and Geodesy)
-            nz (GNS, New Zealand)
-            ga (Geoscience Australia)
-            bev (Austria Federal Office of Metrology and Surveying)
-            bfg (German Agency for water research, only Rinex 3, requires password)
-            jp (GSI, requires password)
-            jeff (My good friend Professor Freymueller!)
-            special (set aside files at UNAVCO for reflectometry users)
-            all (does unavco, sopac, and sonel)
+
+            unavco : (University Navstar Consortium)
+
+            sonel : (global sea level observing system)
+
+            sopac : (Scripps Orbit and Permanent Array Center)
+
+            cddis : (NASA's Archive of Space Geodesy Data)
+
+            ngs : (National Geodetic Survey)
+
+            nrcan : (Natural Resources Canada)
+
+            bkg : (German Agency for Cartography and Geodesy)
+
+            nz : (GNS, New Zealand)
+
+            ga : (Geoscience Australia)
+
+            bev : (Austria Federal Office of Metrology and Surveying)
+
+            bfg : (German Agency for water research, only Rinex 3, requires password)
+
+            jp : (GSI, requires password)
+
+            jeff : (My good friend Professor Freymueller!)
+
+            special : (set aside files at UNAVCO for reflectometry users)
+
+            all : (does unavco, sopac, and sonel)
 
     doy_end : int, optional
         end day of year to be downloaded. This is to create a range from doy to doy_end of days to get the snr files.
@@ -156,7 +203,9 @@ def rinex2snr(station: str, year: int, doy: int, snr: int = 66, orb: str = 'nav'
 
     translator : string, optional
         hybrid (default) : uses a combination of python and fortran to translate the files.
-        fortran : uses fortran to translate (requires the fortran translator executable - see https://github.com/kristinemlarson/gnssrefl)
+
+        fortran : uses fortran to translate (requires the fortran translator executable)
+
         python : uses python to translate. (Warning: This can be very slow)
 
     srate : int, optional
