@@ -70,11 +70,11 @@ def print_badpoints(t,outliersize):
     t : numpy array
         lomb scargle result array of "bad points". Format given below
 
-    outliersize: float
+    outliersize : float
         outlier criterion, in meters
 
     Returns
-    ----------
+    -------
     writes to a file called outliers.txt
 
     """
@@ -105,14 +105,12 @@ def output_names(txtdir, txtfile,csvfile,jsonfile):
     txtdir : str
         the directory where the results should be written out
     txtfile : str
-        name of the output file
+        name of the output file 
     csvfile : boolean
         cl input whether the output file should be csv format
     jsonfile : boolean
         cl input for whether the output file should be in the json format
 
-    default is plain txt file
-
     Returns
     -------
     writetxt : bool
@@ -158,8 +156,8 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
     writes out the subdaily results
 
     Parameters
-    -----------
-    input: str
+    ----------
+    input : str
         output filename
     station : str
         4 character station name, lowercase
@@ -199,7 +197,8 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
     if nr == 0:
         print('No results in this file, so nothing to write out.')
         return
-    print(nr, ' observations will be written to ',outfile)
+    print(nr, ' observations will be written to:')
+    print(outfile)
     N= nr
     fout = open(outfile, 'w+')
     if extra:
@@ -220,19 +219,26 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
         #minute = ctime[3:5]
         # you can either write a csv or text, but not both
         if writecsv:
-            print('this is not up to date')
-            fout.write(" {0:4.0f},{1:3.0f},{2:7.3f},{3:3.0f},{4:6.3f},{5:6.2f},{6:6.2f},{7:6.2f},{8:6.2f},{9:4.0f},{10:3.0f},{11:2.0f},{12:8.5f},{13:6.2f},{14:7.2f},{15:12.6f},{16:1.0f},{17:2.0f},{18:2.0f},{19:2.0f},{20:2.0f},{21:2.0f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], 
-                ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second)))
+            if original:
+                fout.write(" {0:4.0f},{1:3.0f},{2:7.3f},{3:3.0f},{4:6.3f},{5:6.2f},{6:6.2f},{7:6.2f},{8:6.2f},{9:4.0f},{10:3.0f},{11:2.0f},{12:8.5f},{13:6.2f},{14:7.2f},{15:12.6f},{16:1.0f},{17:2.0f},{18:2.0f},{19:2.0f},{20:2.0f},{21:2.0f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second)))
+
+            if extra: 
+                fout.write(" {0:4.0f},{1:3.0f},{2:7.3f},{3:3.0f},{4:6.3f},{5:6.2f},{6:6.2f},{7:6.2f},{8:6.2f},{9:4.0f},{10:3.0f},{11:2.0f},{12:8.5f},{13:6.2f},{14:7.2f},{15:12.6f},{16:1.0f},{17:2.0f},{18:2.0f},{19:2.0f},{20:2.0f},{21:2.0f},{22:7.3f},{23:7.3f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day,hour,minute, int(second), newRH[i],RHdot_corr[i]))
+            if write_IF_corrected:
+                print('this option (IF correction) has not been implemented yet for csv files')
+
         else:
             if write_IF_corrected:
                 fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} {22:7.3f} {23:7.3f} {24:7.3f} \n".format(year, doy, rh,ntv[i,3], 
                     UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], 
                     ntv[i,12],ntv[i,13], ntv[i,14], ntv[i,15], ntv[i,16],month,day, hour,minute, 
                     int(second), ntv[i,22], ntv[i,23], newRH_IF[i] ))
+
             if extra:
                     fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} {22:6.3f} {23:6.3f} \n".format(year, doy, rh, ntv[i,3], 
                         UTCtime,ntv[i,5],ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], 
                         ntv[i,15], ntv[i,16],month,day,hour,minute, int(second), newRH[i], RHdot_corr[i]))
+
             if original:
                 fout.write(" {0:4.0f} {1:3.0f} {2:7.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} {17:2.0f} {18:2.0f} {19:2.0f} {20:2.0f} {21:2.0f} \n".format(year, doy, rh,ntv[i,3],UTCtime,ntv[i,5],
                     ntv[i,6],ntv[i,7],ntv[i,8], ntv[i,9], ntv[i,10],ntv[i,11], ntv[i,12],ntv[i,13], ntv[i,14], 
@@ -427,7 +433,6 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
 
         minAz = float(np.min(tv[:,5])) ; maxAz = float(np.max(tv[:,5]))
 
-        #print(d1,d2)
         two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2)
         stack_two_more(otimes,tv,ii,jj,stats, station, txtdir,sigma,kplt)
         plt.show()
@@ -436,8 +441,13 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
     print_badpoints(tv[ii,:],residuals[ii])
 
     # now write things out - using txtdir variable sent 
-    fname =     txtdir  + '/' + station + '_' + str(year) + '_subdaily_all.txt'
-    fname_new = txtdir  + '/' + station + '_' + str(year) + '_subdaily_edit.txt'
+    if writecsv: 
+        fname =     txtdir  + '/' + station + '_' + str(year) + '_subdaily_all.csv'
+        fname_new = txtdir  + '/' + station + '_' + str(year) + '_subdaily_edit.csv'
+    else:
+        fname =     txtdir  + '/' + station + '_' + str(year) + '_subdaily_all.txt'
+        fname_new = txtdir  + '/' + station + '_' + str(year) + '_subdaily_edit.txt'
+
     extraline = ''
 
     editedtv = tv[jj,:]
@@ -451,6 +461,7 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
     print('Percent of observations removed: ', round(100*(NV-nr)/NV,2))
     
     # now return the names of the output files ... 
+
     return tv,otimes, fname, fname_new
 
 
@@ -496,6 +507,9 @@ def quickTr(year, doy,frachours):
 def fract_to_obstimes(spl_x):
     """
     this does not seem to be used
+
+    Parameters
+    ----------
     spl_x : numpy array
         fractional time 
 
@@ -523,18 +537,26 @@ def fract_to_obstimes(spl_x):
 
 def spline_in_out(x,y,knots_per_day):
     """
-    inputs are numpy arrays of time (in doy) and reflector heights (m)
-    outputs are the spline fit
 
     Parameters
     ----------
     x : numpy of floats
+        time of observations in fractional days
 
     y : numpy of floats
+        reflector heights in meters
 
     knots_per_day : int
+        number of knots per day
+
+    Returns
+    -------
+    xx : numpy of floats
+        regularly spaced observations
+
+    spline(xx): numpy of floats
+        spline value at those times
 
-    note: i have to assume this does not work well with data outages
     """
     Ndays = round(x.max()-x.min())
     numKnots = int(knots_per_day*(Ndays))
@@ -564,7 +586,6 @@ def write_out_header(fout,station,extraline,**kwargs):
     extraline : bool
         not sure why this is here
 
-
     """
     extra_columns = kwargs.get('extra_columns',False)
     IFcol = kwargs.get('IF',False)
@@ -589,11 +610,11 @@ def write_out_header(fout,station,extraline,**kwargs):
 def writejsonfile(ntv,station, outfile):
     """
     subdaily RH values written out in json format
-    inputs: ntv is the variable with concatenated results
 
     Parameters
     -----------
-    ntv : numpy of LSP results
+    ntv : numpy of floats
+        LSP results
 
     station : str
         4 ch station name
@@ -668,301 +689,6 @@ def writejsonfile(ntv,station, outfile):
 
     return True
 
-def rhdot_correction(station,fname,fname_new,pltit,outlierV,**kwargs):
-    """
-
-    Parameters
-    ----------
-    station : string
-        4 char station name
-
-    fname : string
-        input filename for results
-
-    fname_new : string
-        output filename for results
-
-    pltit : boolean 
-        whether you want plots to the screen
-
-    outlierV : float
-       outlier criterion, in meters 
-
-    """
-    outlierV = float(outlierV) #just to make sure - i think it was sending a string
-    # output will go to REFL_CODE/Files
-    xdir = os.environ['REFL_CODE']
-    val = kwargs.get('txtdir',[])
-    if len(val) == 0:
-        txtdir = xdir + '/Files/'
-    else:
-        txtdir = val
-    print('output directory: ', txtdir)
-
-    # this is the old version
-    testing = kwargs.get('testing',False)
-
-
-#   how often do you want velocity computed (per day)
-    perday = 24*20 # so every 3 minutes
-    fs = 10 # fontsize
-    # making a knot every three hours ...
-    # knots_per_day = 8
-    knots_default = 8
-    knots_per_day= kwargs.get('knots',8)
-    print('>>>>>>>>>>>>>>>>>>>> Entering spline fit <<<<<<<<<<<<<<<<<<<<<<<<')
-    print('Input filename:', fname)
-    print('Output filename: ', fname_new)
-    # read in the tvd values which are the output of gnssir
-    # i.e. the reflector heights
-    tvd = np.loadtxt(fname,comments='%')
-    if len(tvd) == 0:
-        print('empty input file')
-        return
-    # sort the data in time
-    ii = np.argsort( (tvd[:,1]+tvd[:,4]/24) ).T
-    tvd = tvd[ii,:]
-
-    NV = len(tvd)
-    # remove a median value from RH
-    medval = np.median(tvd[:,2])
-    xx= tvd[:,2]-medval
-
-    # use 3 sigma for the histogram plot ????
-    Sig = np.std(xx)
-    ij =  np.absolute(xx) < 3*Sig
-    xnew = xx[ij]
-
-    # sure looks like 3 sigma is being removed here! But this would get rid of a real storm surge
-    # perhaps not needed since 3 sigma should have been taken out from the daily values
-    tvd = tvd[ij,:]
-
-    # time variable in days
-    th= tvd[:,1] + tvd[:,4]/24; 
-    # reflector height (meters)
-    h = tvd[:,2]
-    # this is the edot factor - 
-    # this was computed by gnssir as the mean of the tangent(eangles) over an arc,
-    # divided by edot (the tiem rate of change of elevation angle, initially rad/sec,
-    # but then converted to rad/hour).  Thus this parameter has units  rad/(rad/hour) >>>> hours
-    # it is multiplied by RHDot in meters/hour, which gives you a correction value in meters
-    xfac = tvd[:,12]
-    
-    # now get obstimes if they were not passed
-    obstimes = kwargs.get('obstimes',[])
-    if len(obstimes) == 0:
-        print('Calculating obstimes ...')
-        obstimes = g.get_obstimes(tvd)
-
-    # 
-    fillgap = 1/24 # one hour fake values
-    # ???
-    gap = 5/24 # up to five hour gap allowed before warning
-
-    tnew =[] ; ynew =[]; faket = []; 
-    # fill in gaps using variables called tnew and ynew
-    Ngaps = 0
-    for i in range(1,len(th)):
-        d= th[i]-th[i-1] # delta in time in units of days ?
-        if (d > gap):
-            #print(t[i], t[i-1])
-            x0 = th[i-1:i+1]
-            h0 = h[i-1:i+1]
-            print('Gap on doy:', int(np.floor(x0[0])), ' lasting ', round(d*24,2), ' hours ')
-            Ngaps = Ngaps + 1
-            f = scipy.interpolate.interp1d(x0,h0)
-            #f = scipy.interpolate.interp1d(x0,h0,'quadratic')
-            # so this is fake data
-            ttnew = np.arange(th[i-1]+fillgap, th[i], fillgap)
-            yynew = f(ttnew)
-            faket = np.append(faket, ttnew)
-            # now append it to your real data
-            tnew = np.append(tnew,ttnew)
-            ynew = np.append(ynew,yynew)
-        else:
-            tnew = np.append(tnew,th[i])
-            ynew = np.append(ynew,h[i])
-
-    if (Ngaps > 3):
-        print('This is a beta version of the rhdot/spline fit code - and does not work well with gaps. You have been warned!')
-    # sort it just to make sure ...
-    ii = np.argsort( tnew) 
-    tnew = tnew[ii]
-    ynew = ynew[ii]
-
-    Ndays = tnew.max()-tnew.min()
-    numKnots = int(knots_per_day*(Ndays))
-    print('First and last time values', '{0:8.3f} {1:8.3f} '.format (tnew.min(), tnew.max()) )
-    print('Number of RH obs', len(h))
-    print('Average obs per day', '{0:5.1f} '.format (len(h)/Ndays) )
-    print('Knots per day: ', knots_per_day, ' Number of knots: ', numKnots)
-    print('Outlier criterion with respect to spline fit (m): ', outlierV)
-    print('Number of days of data: ', '{0:8.2f}'.format ( Ndays) )
-    # need the first and last knot to be inside the time series ???
-    # 
-    # try this instead - first and last day
-    tt1 = tvd[0,1]
-    tt2 = tvd[-1,1] + 1
-    kdt = knots_per_day/24
-    knots = np.linspace(tt1 + kdt/2, tt2 - kdt/2, numKnots)
-    firstKnot_in_minutes = 15
-    t1 = tnew.min()+firstKnot_in_minutes/60/24
-    t2 = tnew.max()-firstKnot_in_minutes/60/24
-    knots =np.linspace(t1,t2,num=numKnots)
-
-
-    t, c, k = interpolate.splrep(tnew, ynew, s=0, k=3,t=knots,task=-1)
-
-
-    # should i do extrapolate True? it is the default  
-    #spline = interpolate.BSpline(t, c, k, extrapolate=True)
-    spline = interpolate.BSpline(t, c, k, extrapolate=False)
-    # equal spacing in both x and y
-    # evenly spaced data - units of days
-    N = int(Ndays*perday)
-    xx = np.linspace(tnew.min(), tnew.max(), N)
-    spl_x = xx; spl_y = spline(xx)
-
-#  clean up the data a bit
-# make a residual to the spline fit.  Spline is NOT truth
-    resid_spl = h - spline(th) 
-    # good points
-    i = (np.absolute(resid_spl) < outlierV)
-    # bad points
-    j = (np.absolute(resid_spl) > outlierV)
-    # put these in a file if you are interested
-    print_badpoints(tvd[j,:], resid_spl[j])
-    if pltit:
-        #plt.figure()
-        fig=plt.figure(figsize=(10,4))
-
-        #plt.plot(obstimes, h, 'bo', label='Original points',markersize=3)
-        plt.plot(th, h, 'b.', label='Original points',markersize=3)
-        # cannot use this because i do not have the year in the tnew variable
-        #obstimes = fract_to_obstimes(spl_x)
-        plt.plot(spl_x, spl_y, 'r', label='spline')
-        plt.title( station.upper() + ' Reflector Heights')
-        outlierstring = str(outlierV) + '(m) outliers'
-        plt.plot(th[j], h[j], 'c.',label=outlierstring) 
-        plt.ylabel('meters',fontsize=fs)
-        plt.xlabel('days',fontsize=fs)
-        plt.grid()
-        plt.gca().invert_yaxis()
-        plt.legend(loc="upper left")
-        plotname = txtdir + '/' + station + '_rhdot1.png'
-        plt.savefig(plotname,dpi=300)
-        print('png file saved as: ', plotname)
-
-# take out these points
-    th = th[i]; h = h[i]
-    xfac = xfac[i]
-    resid_spl = resid_spl[i]
-    tvd = tvd[i,:]
-
-# taking out first and last six hours as well
-    t1 = float(th[0] + 6/24)
-    t2 = float(th[-1] - 6/24)
-# and again
-    i = (th >= t1) & (th <= t2)
-    th = th[i]; h = h[i]
-    xfac = xfac[i]
-    resid_spl = resid_spl[i]
-    tvd = tvd[i,:]
-
-    #i = (th <= t2)
-    #th = th[i]; h = h[i]
-    #xfac = xfac[i]
-    #resid_spl = resid_spl[i]
-    #tvd = tvd[i,:]
-
-# put the original series without outliers eventually?
-# use first diff to get simple velocity.  
-# 24 hours a day, you asked for perday values by day
-    obsPerHour= perday/24
-        
-    # these are unreliable at beginning and end of the series for clear reasons
-    # these velocities are in meters/hour
-    tvel = spl_x[1:N]
-    yvel = obsPerHour*np.diff(spl_y)
-
-    rhdot_at_th = np.interp(th, tvel, yvel)
-    # this is the RHdot correction. This can be done better - 
-    # this is just a start
-    correction = xfac*rhdot_at_th
-    #  this is where i should do a new spline fit with the corrected RH values
-    # h = h - correction
-
-    if pltit:
-        fig=plt.figure(figsize=(12,6))
-        ax1=fig.add_subplot(311)
-        ijk = np.abs(correction) >  1
-        plt.plot(th, correction,'b.',label='RHcorr')
-        plt.plot(th[ijk], correction[ijk],'rx',label='suspect')
-        plt.title('RHdot Correction',fontsize=fs)
-        plt.ylabel('m',fontsize=fs);
-        plt.grid()
-        plt.setp(ax1.get_xticklabels(), visible=False)
-        plt.xlim((th[0], th[-1]))
-
-        ax2=fig.add_subplot(312)
-        plt.plot(th, rhdot_at_th,'b.',label='at obs')
-        plt.plot(tvel[2:-2], yvel[2:-2], '-',color='orange',label='modeled')
-        plt.title('RHdot in meters per hour',fontsize=fs)
-        plt.ylabel('m/hr',fontsize=fs);
-        plt.legend(loc="best")
-        plt.grid()
-        plt.setp(ax2.get_xticklabels(), visible=False)
-        plt.yticks(fontsize=fs); plt.xticks(fontsize=fs)
-        plt.xlim((th[0], th[-1]))
-
-        ax3=fig.add_subplot(313)
-        label1 = 'w/o RHdot ' + str( round(np.std(resid_spl),2)) + 'm'
-        label2 = 'w/ RHdot ' + str(round(np.std(resid_spl-correction),2)) + 'm'
-        plt.plot(th, resid_spl,'.',color='orange',label= label1)
-        plt.plot(th, resid_spl - correction,'b.',label=label2)
-        plt.plot(th[ijk], resid_spl[ijk] - correction[ijk],'rx',label='suspect')
-        plt.legend(loc="best")
-        plt.xlabel('days of the year',fontsize=fs)
-        plt.ylabel('m',fontsize=fs)
-        plt.yticks(fontsize=fs); plt.xticks(fontsize=fs)
-        plt.title('Reflector Height Residuals to the Spline Fit',fontsize=fs)
-        plt.xlim((th[0], th[-1]))
-        plt.grid()
-
-        plotname = txtdir + '/' + station + '_rhdot2.png'
-        plt.savefig(plotname,dpi=300)
-        print('png file saved as: ', plotname)
-        plt.show()
-
-    print('RMS no RHdot correction (m)', '{0:6.3f}'.format ( np.std(resid_spl)) )
-    print('RMS w/ RHdot correction (m)', '{0:6.3f}'.format ( np.std(resid_spl - correction))  )
-    # this is RH with the RHdot correction
-    correctedRH = resid_spl - correction
-    print('Freq  Bias  Sigma   NumObs ')
-    print('       (m)   (m)       ')
-    biasCorrected_RH = tvd[:,2] - correction
-    for f in [1, 2, 20, 5, 101, 102, 201, 205,207,208]:
-        ff = (tvd[:,10] == f)
-        ret = correctedRH[ff]
-        if len(ret) > 0:
-            print('{0:3.0f} {1:6.2f} {2:6.2f} {3:6.0f}'.format (f, np.mean(ret), np.std(ret), len(ret) ) )
-            biasCorrected_RH[ff] = biasCorrected_RH[ff] - np.mean(ret)
-
-    writecsv = False; writetxt = True
-    extraline = 'outliers removed/two new columns: corrected RH and the RHdot correction applied '
-    newRH = tvd[:,2] - correction
-    write_subdaily(fname_new,station,tvd,writecsv,extraline,newRH=newRH, RHdot_corr=correction)
-    nr,nc = tvd.shape
-    print('Percent of observations removed:', round(100*(NV-nr)/NV,2))
-
-    # doy
-    newt = tvd[:,1] + tvd[:,4]/24 ; 
-    residual = redo_spline(newt, newRH, biasCorrected_RH,pltit,txtdir,station,testing)
-
-
-    return tvd, correction 
-
-
 
 def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
     """
@@ -986,6 +712,7 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
 
     d1 : int
         minimum day of year
+
     d2 : int
         maximum day of year
 
@@ -1064,7 +791,8 @@ def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
 
     Parameters
     ----------
-    otimes - datetime object
+    otimes - numpy array of datetime objects ?
+        observation times
 
     tv - variable with the gnssrefl results
 
@@ -1138,13 +866,40 @@ def apply_new_constraints(tv,azim1,azim2,ampl,peak2noise,d1,d2,h1,h2):
     """
     cleaning up the main code. this sorts data and applies various "commandline" constraints
     tv is the full set of results from gnssrefl
-    t and rh are just time (in fractional doy) and reflector height
-    other inputs:
-    azim1-aimz2 - azimuth constraints in degrees
-    ampl is amplitude of the periodogram (volts/volts)
-    d1 and d2 are days of year
-    peak2noise 
 
+    Parameters
+    ----------
+    tv : numpy array
+        lsp results
+    azim1 : float
+        min azimuth (deg)
+    azim2 : float
+        max azimuth (deg)
+    ampl : float
+        required amplitude for periodogram
+    peak2noise : float
+        require peak2noise criterion
+    d1 : int
+        min day of year
+    d2 : int
+        max day of year
+    h1 : float
+        min reflector height (m)
+    h2 : float
+        max reflector height (m)
+
+    Returns
+    -------
+    tv : numpy array
+        edited from input
+    t : numpy of floats
+        crude time for obs, in fractional days
+    rh : numpy of floats
+        reflector heights (m)
+    firstdoy : int
+        first day of year
+    lastdoy : int 
+        last day of year
     """
     nr,nc=tv.shape
     tvoriginal = tv
@@ -1198,140 +953,13 @@ def apply_new_constraints(tv,azim1,azim2,ampl,peak2noise,d1,d2,h1,h2):
 
     return tv,t,rh,firstdoy,lastdoy
 
-def redo_spline(tnew,ynew,biasCorr_ynew,pltit,txtdir,station,testing):
-    """
-    having calculated and applied RHdot correction
-    AND applied the frequency biases, create new plots
-
-    Parameters
-    ----------
-    tnew : numpy array
-        day of year 
-    ynew : numpy array
-        float of reflector heights rhdot corrected (meters)
-    ynew : numpy array
-        float of reflector heights rhdot and freq bias corrected (meters)
-    pltit : boolean
-        plots to the screen
-    txtdir : string
-         directory for output (e.g. $REFL_CODE/Files)
-    station : string
-        station name used for the plot titles and filenames
-    testing : boolean
-        turns off "try" so you can see the error messages
-
-    Returns
-    -------
-    res : numpy array
-        residuals to spline fit, in meters
-
-    """
-    fs = 10 # font size
-    ynew = biasCorr_ynew
-    # now sort them again ....
-    ii = np.argsort(tnew)
-    tnew = tnew[ii]
-    ynew = ynew[ii]
-    outlierV = 0.5 # for now
-
-    # making a knot every three hours ...
-    knots_per_day = 8
-    Ndays = tnew.max()-tnew.min()
-    numKnots = int(knots_per_day*(Ndays))
-    NV = len(ynew)
-    print('>>>>>>>>>>>>>>>>>>> Redo Spline <<<<<<<<<<<<<<<<<<<<<<<<<<<<')
-    print('First and last time values', '{0:8.3f} {1:8.3f} '.format (tnew.min(), tnew.max()) )
-    print('Number of RH obs', NV)
-    print('Number of days of data: ', '{0:8.2f}'.format ( Ndays) )
-    print('Average obs per day', '{0:5.1f} '.format (NV/Ndays) )
-    print('Number of knots: ', numKnots)
-    # need the first and last knot to be inside the time series
-    firstKnot_in_minutes = 15
-    t1 = tnew.min()+firstKnot_in_minutes/60/24
-    t2 = tnew.max()-firstKnot_in_minutes/60/24
-    # try this
-    #
-    knots =np.linspace(t1,t2,num=numKnots)
-
-    # this crashes because I did not take care of the gaps.
-    if testing:
-        t, c, k = interpolate.splrep(tnew, ynew, s=0, k=3,t=knots,task=-1)
-        spline = interpolate.BSpline(t, c, k, extrapolate=False)
-    else: 
-        try:
-            t, c, k = interpolate.splrep(tnew, ynew, s=0, k=3,t=knots,task=-1)
-            spline = interpolate.BSpline(t, c, k, extrapolate=False)
-        except:
-            print('crashed on the interpolation stage')
-            sys.exit()
-
-    # user specifies how many values per day you want to send back to the user
-
-    # should i do extrapolate True? it is the default  - could make it periodic?
-    #spline = interpolate.BSpline(t, c, k, extrapolate=True)
-
-    # evenly spaced data - units of days
-    perday = 48 # so every 30 minutes in this case
-    N = int(Ndays*perday)
-    xx = np.linspace(tnew.min(), tnew.max(), N)
-    spl_x = xx; spl_y = spline(xx)
-    spline_at_tnew = spline(tnew)
-    N = len(spl_x)
-    kristine = False
-    if kristine:
-        ftest = open('Ktesting.txt', 'w+')
-        myyear = 2022
-        for i in range(0,N):
-            mjdish = g.fdoy2mjd(myyear,spl_x[i])
-            ftest.write('{0:9.4f} {1:7.3f} {2:12.6f} \n'.format( spl_x[i], spl_y[i], mjdish))
-
-        ftest.close()
-        
-
-    plt.subplot(211)
-    plt.plot(tnew,ynew,'k.')
-    plt.plot(tnew,biasCorr_ynew,'b.',label='with freq/rhdot corr')
-    plt.plot(spl_x, spl_y,'-',color='orange',label='spline fit')
-    plt.title(station + ' RH Obs and new spline fit after freq bias removed')
-
-    plt.legend(loc="upper right")
-    plt.xlabel('day of year'); 
-    plt.ylabel('meters')
-    plt.grid()
-    plt.gca().invert_yaxis()
-
-    rms = np.std(ynew-spline_at_tnew)
-    newrms = str(round(rms,3))
-    print('std (m)', newrms)
-    ii = np.abs(ynew-spline_at_tnew) > 3*rms
-    jj = np.abs(ynew-spline_at_tnew) < 3*rms
-    res = ynew-spline_at_tnew
-    plt.subplot(212)
-    plt.plot(tnew,res,'b.', label='RH rms:' + newrms + ' m')
-    plt.plot(tnew[ii],res[ii],'r.',label='3sigma outliers')
-    #plt.title('residuals')
-    plt.xlabel('day of year'); 
-    plt.ylabel('meters')
-    plt.legend(loc="upper right")
-    plt.grid()
-    plt.gca().invert_yaxis()
-    Ntot = len(res)
-    Nout = len(res[ii])
-    print('Percentage of 3-sigma outliers', round(100*Nout/Ntot,2))
-    #
-    plotname = txtdir + '/' + station + '_final.png'
-    plt.savefig(plotname,dpi=300)
-    print('png file saved as: ', plotname)
-    if pltit:
-        plt.show()
-
-    return res
 
 def rhdot_plots(th,correction,rhdot_at_th, tvel,yvel,fs,station,txtdir):
     """
     make rhdot correction plots
 
     Parameters
+    ----------
     th : numpy array
         time of obs, day of year
     correction : numpy array
@@ -1360,16 +988,15 @@ def rhdot_plots(th,correction,rhdot_at_th, tvel,yvel,fs,station,txtdir):
     #plt.xlim((plot_begin, plot_end))
 
     plt.subplot(2,1,2)
+    A1 = np.min(th) ; A2 = np.max(th)
+    jj = (tvel >= A1) & (tvel <= A2)
     plt.plot(th, rhdot_at_th,'o',label='at GNSS obs')
-    plt.plot(tvel, yvel,'-', label='spline fit')
+    plt.plot(tvel[jj], yvel[jj],'-', label='spline fit')
     plt.legend(loc="upper left")
-
     plt.grid()
     plt.title('surface velocity')
-    plt.ylim((-1.5,1.5))
-    plt.ylabel('meters/hour')
-    plt.xlabel('days of the year')
-    plt.xlim((np.min(th), np.max(th)))
+    plt.ylabel('meters/hour'); plt.xlabel('days of the year')
+    plt.xlim((A1,A2))
     g.save_plot(txtdir + '/' + station + '_rhdot3.png')
 
 
@@ -1553,7 +1180,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     Ndays = tnew.max()-tnew.min()
     numKnots = int(knots_per_day*(Ndays))
     print('First and last time values in the spline', '{0:8.3f} {1:8.3f} '.format (tnew.min(), tnew.max()) )
-    print('Number of RH obs and Days ', len(h), Ndays)
+    print('Number of RH obs and Days ', len(h), np.round(Ndays,3))
     print('Average num of RH obs per day', '{0:5.1f} '.format (len(h)/Ndays) )
     print('Knots per day: ', knots_per_day, ' Number of knots: ', numKnots)
     # currently using 3 sigma
@@ -1584,6 +1211,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     obsPerHour= perday/24
 
     fig=plt.figure(figsize=(10,6))
+
     plt.subplot(2,1,1)
 
     tvel = spl_x[1:N]
@@ -1593,16 +1221,14 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     correction = xfac*rhdot_at_th
     correctedRH = h-correction
 
-
-
     # this is RH with the RHdot correction
     residual_before = h - spl_at_GPS_times
     residual_after = correctedRH - spl_at_GPS_times
     sigmaBefore = np.std(residual_before)
     sigmaAfter  = np.std(residual_after)
 
-    label1 = 'w/o RHdot ' + str(np.round(sigmaBefore,2)) + 'm'
-    label2 = 'w RHdot ' + str(np.round(sigmaAfter,2)) + 'm'
+    label1 = 'w/o RHdot ' + str(np.round(sigmaBefore,3)) + 'm'
+    label2 = 'w RHdot ' + str(np.round(sigmaAfter,3)) + 'm'
 
     plt.plot(th, h, 'b.', label=label1,markersize=4)
     iw = (spl_x > th[0]) & (spl_x < th[-1])
@@ -1651,7 +1277,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     # update the residual vector as well
     residual_after = residual_after[ii]
 
-    # make this plot as well
+    # make the RHdot plot as well
     rhdot_plots(th,correction,rhdot_at_th, tvel,yvel,fs,station,txtdir)
 
     writecsv = False ; extraline = ''
@@ -1689,7 +1315,6 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
             print('{0:3.0f} {1:7.3f} {2:7.3f} {3:6.0f}'.format (f, bias, sig, len(ret) ) )
 
 
-   # try extending the time series to improve spline fit
     tvd = np.loadtxt(fname_new,comments='%')
 
     # now try to write the bias corrected values
@@ -1722,29 +1347,44 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     th_even = np.linspace(th[0], th[-1],half_hourly );
     spline_whole_time = spline(th_even)
 
+    newsigma = np.std(h-spline_at_GPS)
+    strsig = str(round(newsigma,3)) + '(m)'
+
+    # this is last plot -the one with new spline
+
     fig=plt.figure(figsize=(10,6))
     plt.subplot(2,1,1)
-    plt.plot(th, h, '.', label='RH with RHdot')
+    plt.plot(th, h, '.', label='RH with RHdot/IFcorr ' + strsig)
     plt.plot(th_even, spline_whole_time, '-',label='newspline')
     plt.legend(loc="upper left")
     plt.grid()
     plt.gca().invert_yaxis()
     plt.ylabel('meters')
-    plt.title('New spline with RHdot corr and initial outliers removed')
+    plt.title('New spline with RHdot corr/IF biases/initial 3sigma outliers removed')
 
     plt.subplot(2,1,2)
-    plt.plot(th, h-spline_at_GPS, '.',label='all')
+    plt.plot(th, h-spline_at_GPS, '.',label='all residuals')
     plt.title('Residuals to new spline fit')
     plt.grid()
     plt.ylabel('meters')
     plt.xlabel('days of the year')
-    newsigma = np.std(h-spline_at_GPS)
+
     # identify 3 sigma outliers
     ii = np.abs(h-spline_at_GPS)/newsigma > 3
     plt.plot(th[ii], (h-spline_at_GPS)[ii], '.',label='3 sigma')
     plt.legend(loc="upper left")
     print('RMS with frequency bias taken out (m) ', np.round(newsigma,3)  )
     g.save_plot(txtdir + '/' + station + '_rhdot4.png')
+
+    # was looking at issue of delT being too big
+    if  False:
+        plt.figure()
+        res = (h-spline_at_GPS)
+        plt.plot( tvd[ii,14],  res[ii], 'o', label='outlier')
+        plt.plot( tvd[:,14], res, '.',label='residuals')
+        plt.xlabel('delta Time (minutes)')
+
+
     if pltit:
         plt.show()
 
