@@ -28,6 +28,7 @@ def parse_arguments():
     parser.add_argument("-minvalperday", default=None, type=int, help="minimum number of satellite tracks needed each day. Default is 10")
     parser.add_argument("-snow_filter", default=None, type=str, help="boolean for attempting to remove days contaminated by snow")
     parser.add_argument("-circles", default=None, type=str, help="circles instead of lines for the final VWC plot ")
+    parser.add_argument("-subdir", default=None, type=str, help="use non-default subdirectory for output files")
 
     args = parser.parse_args().__dict__
 
@@ -136,7 +137,7 @@ def load_avg_phase(station,fr):
         4 character station ID, lowercase
 
     Returns
-    --------
+    -------
     avg_exist : boolean
 
     avg_date : ??
@@ -178,19 +179,35 @@ def load_sat_phase(station, year, year_end, freq):
     ----------
     station : str
         four character station name
-
     year : integer
         beginning year
-
     year_end : integer
         ending year
-
     freq : integer
         GPS frequency (1,20 allowed)
 
     Returns
     -------
-    reflector heights and amplitudes
+    dataexist : bool
+        whether data found?
+    year : numpy array of int
+        full years
+    doy : numpy array of int
+        days of year
+    hr : float
+        fractional day (UTC)
+    ph : float
+        phases (deg)
+    azdata : float
+        azimuths (deg)
+    ssat : int
+        satellites (deg)
+    rh : float
+        reflector height (m)
+    amp : float
+        amplitudes of peak LSP 
+
+    results : ??
 
     """
     print('Requested frequency: ', freq)
@@ -204,7 +221,7 @@ def load_sat_phase(station, year, year_end, freq):
     #    override = np.loadtxt(xfile, comments='%')
     #    found_override = True
 
-    dir = Path(os.environ["REFL_CODE"])
+    thedir = Path(os.environ["REFL_CODE"])
 
     if not year_end:
         year_end = year
@@ -212,7 +229,7 @@ def load_sat_phase(station, year, year_end, freq):
     results = []
     for year in np.arange(year, year_end+1):
         # where the results are stored
-        data_dir = dir / str(year) / 'phase' / station
+        data_dir = thedir / str(year) / 'phase' / station
         local_results = read_files_in_dir(data_dir)
         if local_results:
             results.extend(local_results)
@@ -250,6 +267,7 @@ def load_sat_phase(station, year, year_end, freq):
         ssat = results[6]
         rh = results[13]
         amp = results[15]
+
     return dataexist, year, doy, hr, ph, azdata, ssat, rh, amp, results
 
 
@@ -280,7 +298,8 @@ def normAmp(amp, basepercent):
 
 
 def vwc(station: str, year: int, year_end: int = None, fr: int = 20, plt2screen: bool = True, screenstats: bool = False, 
-        min_req_pts_track: int = 50, polyorder: int = -99, minvalperday: int = 10, snow_filter: bool = False, circles: bool=False):
+        min_req_pts_track: int = 50, polyorder: int = -99, minvalperday: int = 10, 
+        snow_filter: bool = False, circles: bool=False, subdir: str=None):
     """
     Code to pick up phase results, make quadrant plots, daily average files and converts to volumetric water content (VWC).
 
@@ -322,6 +341,9 @@ def vwc(station: str, year: int, year_end: int = None, fr: int = 20, plt2screen:
     circles : boolean
         whether you want circles in the final plot (lines are default)
 
+    subdir: str
+        subdirectory in $REFL_CODE/Files for plots and text file outputs
+
     Returns
     -------
 
@@ -344,6 +366,13 @@ def vwc(station: str, year: int, year_end: int = None, fr: int = 20, plt2screen:
     if not year_end:
         year_end = year
 
+    # default is station name
+    if subdir == None:
+        subdir = station 
+
+    # make sure subdirectory exists
+    g.set_subdir(subdir)
+
     if not plt2screen:
         print('no plots will come to screen. Will only be saved.')
 
@@ -386,7 +415,7 @@ def vwc(station: str, year: int, year_end: int = None, fr: int = 20, plt2screen:
         print('Try lowering minvalperday at the command line')
         sys.exit()
     if (nr < 15 ) and (minvalperday==10):
-        print('The code thinks you are using ', nr, ' satellite tracks but you are requiring the default minvalperday.')
+        print('The code thinks you are using ', nr, ' satellite tracks but that is pretty close to the default (', minvalperday, ')')
         print('This could be problematic. Try lowering minvalperday at the command line')
         sys.exit()
 
@@ -518,7 +547,7 @@ def vwc(station: str, year: int, year_end: int = None, fr: int = 20, plt2screen:
                     plt.gcf().autofmt_xdate()
 
 
-    plot_path = f'{xdir}/Files/{station}_az_phase.png'
+    plot_path = f'{xdir}/Files/{subdir}/{station}_az_phase.png'
     print(f"Saving to {plot_path}")
     plt.savefig(plot_path)
 
@@ -537,17 +566,18 @@ def vwc(station: str, year: int, year_end: int = None, fr: int = 20, plt2screen:
     #minvalperday = 10 - now an input
     if writeout:
 
-        tv = qp.write_avg_phase(station, phase, fr,year,year_end,minvalperday,vxyz)
+        tv = qp.write_avg_phase(station, phase, fr,year,year_end,minvalperday,vxyz,subdir)
         print('Number of daily phase measurements ', len(tv))
         if len(tv) < 1:
             print('No results - perhaps minvalperday or min_req_pts_track are too stringent')
             sys.exit()
 
+        # make datetime date array
         datetime_dates = [datetime.strptime(f'{int(yr)} {int(d)}', '%Y %j') for yr, d in zip(tv[:, 0], tv[:, 1])]
 
-        qp.daily_phase_plot(station, fr,datetime_dates, tv,xdir)
+        qp.daily_phase_plot(station, fr,datetime_dates, tv,xdir,subdir)
 
-        qp.convert_phase(station, year, year_end, plt2screen,fr,polyorder,circles)
+        qp.convert_phase(station, year, year_end, plt2screen,fr,polyorder,circles,subdir)
 
 
 def main():
